aboutsummaryrefslogtreecommitdiff
path: root/src/conversion.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/conversion.hpp')
-rw-r--r--src/conversion.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/conversion.hpp b/src/conversion.hpp
index 0bdf82d..6f13342 100644
--- a/src/conversion.hpp
+++ b/src/conversion.hpp
@@ -3,7 +3,7 @@
#include <ctre.hpp>
#include <string_view>
-constexpr unsigned int NUMBER_BASE = 10U;
+constexpr uint32_t NUMBER_BASE = 10U;
template <typename ResultType>
class ConversionResult
@@ -24,9 +24,9 @@ static constexpr auto IS_VALID_UINT = ctll::fixed_string("^[0-9]+$");
static constexpr auto IS_UINT_IN_RANGE = ctll::fixed_string("^[0-9]{1,19}$");
/**
- * Converts a string to a unsigned integer.
+ * Converts a string to a uint32_teger.
*
* @param str A string that possibly is a unsigned integer
* @returns A conversion result
*/
-ConversionResult<unsigned int> str_to_uint(const std::string_view &str);
+ConversionResult<uint32_t> str_to_uint(const std::string_view &str);
@@ -24,9 +24,9 @@ static constexpr auto IS_VALID_UINT = ctll::fixed_string("^[0-9]+$");
*
- * @param str A string that possibly is a unsigned integer
+ * @param str A string that possibly is a uint32_teger
* @returns A conversion result
*/